==> mingw-w64-clang-aarch64-kholidays-6.3.0-1-any.pkg.tar.zst: clangarm64/include/KF6/KHolidays/kholidays/kholidays_export.h <==

#ifndef KHOLIDAYS_EXPORT_H
#define KHOLIDAYS_EXPORT_H

#ifdef KHOLIDAYS_STATIC_DEFINE
#  define KHOLIDAYS_EXPORT
#  define KHOLIDAYS_NO_EXPORT
#else
#  ifndef KHOLIDAYS_EXPORT
#    ifdef KF6Holidays_EXPORTS
        /* We are building this library */
#      define KHOLIDAYS_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define KHOLIDAYS_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef KHOLIDAYS_NO_EXPORT
#    define KHOLIDAYS_NO_EXPORT 
#  endif
#endif

#ifndef KHOLIDAYS_DECL_DEPRECATED
#  define KHOLIDAYS_DECL_DEPRECATED __declspec(deprecated)
#endif

#ifndef KHOLIDAYS_DECL_DEPRECATED_EXPORT
#  define KHOLIDAYS_DECL_DEPRECATED_EXPORT KHOLIDAYS_EXPORT KHOLIDAYS_DECL_DEPRECATED
#endif

#ifndef KHOLIDAYS_DECL_DEPRECATED_NO_EXPORT
#  define KHOLIDAYS_DECL_DEPRECATED_NO_EXPORT KHOLIDAYS_NO_EXPORT KHOLIDAYS_DECL_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KHOLIDAYS_NO_DEPRECATED
#    define KHOLIDAYS_NO_DEPRECATED
#  endif
#endif
#include <kholidays_version.h>

#define KHOLIDAYS_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

/* Take any defaults from group settings */
#if !defined(KHOLIDAYS_NO_DEPRECATED) && !defined(KHOLIDAYS_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  ifdef KF_NO_DEPRECATED
#    define KHOLIDAYS_NO_DEPRECATED
#  elif defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#    define KHOLIDAYS_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#  endif
#endif
#if !defined(KHOLIDAYS_DISABLE_DEPRECATED_BEFORE_AND_AT) && defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  define KHOLIDAYS_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#endif

#if !defined(KHOLIDAYS_NO_DEPRECATED_WARNINGS) && !defined(KHOLIDAYS_DEPRECATED_WARNINGS_SINCE)
#  ifdef KF_NO_DEPRECATED_WARNINGS
#    define KHOLIDAYS_NO_DEPRECATED_WARNINGS
#  elif defined(KF_DEPRECATED_WARNINGS_SINCE)
#    define KHOLIDAYS_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#  endif
#endif
#if !defined(KHOLIDAYS_DEPRECATED_WARNINGS_SINCE) && defined(KF_DEPRECATED_WARNINGS_SINCE)
#  define KHOLIDAYS_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#endif

#if defined(KHOLIDAYS_NO_DEPRECATED)
#  undef KHOLIDAYS_DEPRECATED
#  define KHOLIDAYS_DEPRECATED_EXPORT KHOLIDAYS_EXPORT
#  define KHOLIDAYS_DEPRECATED_NO_EXPORT KHOLIDAYS_NO_EXPORT
#elif defined(KHOLIDAYS_NO_DEPRECATED_WARNINGS)
#  define KHOLIDAYS_DEPRECATED
#  define KHOLIDAYS_DEPRECATED_EXPORT KHOLIDAYS_EXPORT
#  define KHOLIDAYS_DEPRECATED_NO_EXPORT KHOLIDAYS_NO_EXPORT
#else
#  define KHOLIDAYS_DEPRECATED KHOLIDAYS_DECL_DEPRECATED
#  define KHOLIDAYS_DEPRECATED_EXPORT KHOLIDAYS_DECL_DEPRECATED_EXPORT
#  define KHOLIDAYS_DEPRECATED_NO_EXPORT KHOLIDAYS_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define KHOLIDAYS_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define KHOLIDAYS_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef KHOLIDAYS_NO_DEPRECATED
#  define KHOLIDAYS_DISABLE_DEPRECATED_BEFORE_AND_AT KHOLIDAYS_VERSION
#endif
#ifdef KHOLIDAYS_NO_DEPRECATED_WARNINGS
#  define KHOLIDAYS_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef KHOLIDAYS_DEPRECATED_WARNINGS_SINCE
#  ifdef KHOLIDAYS_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define KHOLIDAYS_DEPRECATED_WARNINGS_SINCE KHOLIDAYS_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define KHOLIDAYS_DEPRECATED_WARNINGS_SINCE KHOLIDAYS_VERSION
#  endif
#endif

#ifndef KHOLIDAYS_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define KHOLIDAYS_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef KHOLIDAYS_DEPRECATED
#  define KHOLIDAYS_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KHOLIDAYS_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define KHOLIDAYS_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#endif /* KHOLIDAYS_EXPORT_H */

==> mingw-w64-clang-aarch64-kholidays-6.18.0-1-any.pkg.tar.zst: clangarm64/include/KF6/KHolidays/kholidays/kholidays_export.h <==

#ifndef KHOLIDAYS_EXPORT_H
#define KHOLIDAYS_EXPORT_H

#ifdef KHOLIDAYS_STATIC_DEFINE
#  define KHOLIDAYS_EXPORT
#  define KHOLIDAYS_NO_EXPORT
#else
#  ifndef KHOLIDAYS_EXPORT
#    ifdef KF6Holidays_EXPORTS
        /* We are building this library */
#      define KHOLIDAYS_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define KHOLIDAYS_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef KHOLIDAYS_NO_EXPORT
#    define KHOLIDAYS_NO_EXPORT 
#  endif
#endif

#ifndef KHOLIDAYS_DECL_DEPRECATED
#  define KHOLIDAYS_DECL_DEPRECATED __declspec(deprecated)
#endif

#ifndef KHOLIDAYS_DECL_DEPRECATED_EXPORT
#  define KHOLIDAYS_DECL_DEPRECATED_EXPORT KHOLIDAYS_EXPORT KHOLIDAYS_DECL_DEPRECATED
#endif

#ifndef KHOLIDAYS_DECL_DEPRECATED_NO_EXPORT
#  define KHOLIDAYS_DECL_DEPRECATED_NO_EXPORT KHOLIDAYS_NO_EXPORT KHOLIDAYS_DECL_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KHOLIDAYS_NO_DEPRECATED
#    define KHOLIDAYS_NO_DEPRECATED
#  endif
#endif
#include <kholidays_version.h>

#define KHOLIDAYS_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

/* Take any defaults from group settings */
#if !defined(KHOLIDAYS_NO_DEPRECATED) && !defined(KHOLIDAYS_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  ifdef KF_NO_DEPRECATED
#    define KHOLIDAYS_NO_DEPRECATED
#  elif defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#    define KHOLIDAYS_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#  endif
#endif
#if !defined(KHOLIDAYS_DISABLE_DEPRECATED_BEFORE_AND_AT) && defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  define KHOLIDAYS_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#endif

#if !defined(KHOLIDAYS_NO_DEPRECATED_WARNINGS) && !defined(KHOLIDAYS_DEPRECATED_WARNINGS_SINCE)
#  ifdef KF_NO_DEPRECATED_WARNINGS
#    define KHOLIDAYS_NO_DEPRECATED_WARNINGS
#  elif defined(KF_DEPRECATED_WARNINGS_SINCE)
#    define KHOLIDAYS_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#  endif
#endif
#if !defined(KHOLIDAYS_DEPRECATED_WARNINGS_SINCE) && defined(KF_DEPRECATED_WARNINGS_SINCE)
#  define KHOLIDAYS_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#endif

#if defined(KHOLIDAYS_NO_DEPRECATED)
#  undef KHOLIDAYS_DEPRECATED
#  define KHOLIDAYS_DEPRECATED_EXPORT KHOLIDAYS_EXPORT
#  define KHOLIDAYS_DEPRECATED_NO_EXPORT KHOLIDAYS_NO_EXPORT
#elif defined(KHOLIDAYS_NO_DEPRECATED_WARNINGS)
#  define KHOLIDAYS_DEPRECATED
#  define KHOLIDAYS_DEPRECATED_EXPORT KHOLIDAYS_EXPORT
#  define KHOLIDAYS_DEPRECATED_NO_EXPORT KHOLIDAYS_NO_EXPORT
#else
#  define KHOLIDAYS_DEPRECATED KHOLIDAYS_DECL_DEPRECATED
#  define KHOLIDAYS_DEPRECATED_EXPORT KHOLIDAYS_DECL_DEPRECATED_EXPORT
#  define KHOLIDAYS_DEPRECATED_NO_EXPORT KHOLIDAYS_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define KHOLIDAYS_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define KHOLIDAYS_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef KHOLIDAYS_NO_DEPRECATED
#  define KHOLIDAYS_DISABLE_DEPRECATED_BEFORE_AND_AT KHOLIDAYS_VERSION
#endif
#ifdef KHOLIDAYS_NO_DEPRECATED_WARNINGS
#  define KHOLIDAYS_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef KHOLIDAYS_DEPRECATED_WARNINGS_SINCE
#  ifdef KHOLIDAYS_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define KHOLIDAYS_DEPRECATED_WARNINGS_SINCE KHOLIDAYS_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define KHOLIDAYS_DEPRECATED_WARNINGS_SINCE KHOLIDAYS_VERSION
#  endif
#endif

#ifndef KHOLIDAYS_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define KHOLIDAYS_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef KHOLIDAYS_DEPRECATED
#  define KHOLIDAYS_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KHOLIDAYS_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define KHOLIDAYS_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#if KHOLIDAYS_DEPRECATED_WARNINGS_SINCE >= 0x60f00
#  define KHOLIDAYS_DEPRECATED_VERSION_6_15(text) KHOLIDAYS_DECL_DEPRECATED_TEXT(text)
#else
#  define KHOLIDAYS_DEPRECATED_VERSION_6_15(text)
#endif
#define KHOLIDAYS_DEPRECATED_VERSION_6(minor, text)      KHOLIDAYS_DEPRECATED_VERSION_6_##minor(text)
#define KHOLIDAYS_DEPRECATED_VERSION(major, minor, text) KHOLIDAYS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
#define KHOLIDAYS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KHOLIDAYS_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
#  define KHOLIDAYS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KHOLIDAYS_DEPRECATED_VERSION(major, minor, text)
#  define KHOLIDAYS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KHOLIDAYS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#else
#  define KHOLIDAYS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
#  define KHOLIDAYS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#endif

#endif /* KHOLIDAYS_EXPORT_H */
